{*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Angular notch filter parameters for window glass echoe'
      + 's","type":"object","required":["angle","range_mean","amplitude_mean"],'
      + '"$schema":"http://json-schema.org/draft-04/schema#","title":"Angular '
      + 'Notch Filter","properties":{"angle":{"description":"Angle [deg]","item'
      + 's":{"type":"number"},"type":"array"},"range_mean":{"description":"Mean'
      + ' range [m]","items":{"type":"number"},"type":"array"},"amplitude_mean"'
      + ':{"description":"Mean amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"ran'
      + 'ge_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,'
      + '0.0675,0.06475],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Atmospheric parameters","type":"object","required":["t'
      + 'emperature","pressure","rel_humidity","pressure_sl","amsl","group_velo'
      + 'city","attenuation","wavelength"],"$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","title":"Atmospheric '
      + 'Parameters","properties":{"attenuation":{"description":"Atmospheric '
      + 'attenuation '
      + '[1/km]","type":"number"},"wavelength":{"description":"Laser wavelength'
      + ' [nm]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"pressure":{"description":"Pressure along '
      + 'measurment path '
      + '[mbar]","type":"number"},"group_velocity":{"description":"Group '
      + 'velocity of laser beam '
      + '[m/s]","type":"number"},"temperature":{"description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]","type":"number"},"amsl":{"description":"Height above mean '
      + 'sea level (AMSL) [m]","type":"number"}}}'
    );

    Example : (''
      + '{"attenuation":0.028125,"wavelength":1550,"pressure_sl":970,"rel_humid'
      + 'ity":63,"pressure":970,"group_velocity":299711000.0,"temperature":7,"a'
      + 'msl":0}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Laser beam geometry details","type":"object","required'
      + '":["beam_exit_diameter","beam_divergence"],"$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","title":"Beam '
      + 'Geometry","properties":{"beam_divergence":{"description":"Beam '
      + 'divergence in far field [rad]","exclusiveMinimum":false,"minimum":0,"t'
      + 'ype":"number"},"beam_exit_diameter":{"description":"Beam width at exit'
      + ' aperture [m]","exclusiveMinimum":false,"minimum":0,"type":"number"}}}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"List of control object type definitions","definitions"'
      + ':{"checkerboard2x2":{"description":"checkerboard 2 by 2","allOf":[{"$r'
      + 'ef":"#/definitions/common"},{"description":"checkerboard specific prop'
      + 'erties","required":["shape","square_length"],"properties":{"square_len'
      + 'gth":{"description":"length of a square of the checkerboard in meters"'
      + ',"exclusiveMinimum":true,"minimum":0,"type":"number"},"shape":{"descri'
      + 'ption":"shape identifier","enum":["checkerboard2x2"],"type":"string"}}'
      + ',"type":"object"}],"type":"object"},"cylinder":{"description":"cylinde'
      + 'r","allOf":[{"$ref":"#/definitions/common"},{"description":"cylinder '
      + 'specific properties","required":["shape","diameter","height"],"propert'
      + 'ies":{"diameter":{"description":"diameter in meters","exclusiveMinimum'
      + '":true,"minimum":0,"type":"number"},"height":{"description":"height in'
      + ' meters","exclusiveMinimum":true,"minimum":0,"type":"number"},"shape":'
      + '{"description":"shape identifier","enum":["cylinder"],"type":"string"}'
      + '},"type":"object"}],"type":"object"},"circular_disk":{"description":"c'
      + 'ircular disk","allOf":[{"$ref":"#/definitions/common"},{"description":'
      + '"circular disk specific properties","required":["shape","diameter"],"p'
      + 'roperties":{"diameter":{"description":"diameter in meters","exclusiveM'
      + 'inimum":true,"minimum":0,"type":"number"},"offset":{"description":"off'
      + 'set in meters, e.g. reflector constant '
      + '(optional)","type":"number"},"shape":{"description":"shape identifier"'
      + ',"enum":["circular_disk"],"type":"string"}},"type":"object"}],"type":"'
      + 'object"},"sphere":{"description":"sphere","allOf":[{"$ref":"#/definiti'
      + 'ons/common"},{"description":"sphere specific properties","required":["'
      + 'shape","diameter"],"properties":{"diameter":{"description":"diameter '
      + 'in meters","exclusiveMinimum":true,"minimum":0,"type":"number"},"shape'
      + '":{"description":"shape identifier","enum":["sphere"],"type":"string"}'
      + '},"type":"object"}],"type":"object"},"rectangle":{"description":"recta'
      + 'ngle","allOf":[{"$ref":"#/definitions/common"},{"description":"rectang'
      + 'le specific properties","required":["shape","length","width"],"propert'
      + 'ies":{"length":{"description":"length in meters","exclusiveMinimum":tr'
      + 'ue,"minimum":0,"type":"number"},"width":{"description":"width in meter'
      + 's","exclusiveMinimum":true,"minimum":0,"type":"number"},"shape":{"enum'
      + '":["rectangle"],"type":"string"}},"type":"object"}],"type":"object"},"'
      + 'common":{"description":"common object properties","required":["name","'
      + 'shape"],"properties":{"name":{"description":"unique type identifier","'
      + 'type":"string","minLength":3},"description":{"description":"string '
      + 'describing the '
      + 'object","type":"string"},"surface_type":{"description":"surface '
      + 'material type","enum":["retro_reflective_foil","diffuse"],"type":"stri'
      + 'ng"},"shape":{"description":"shape identifier","enum":["rectangle","ch'
      + 'eckerboard2x2","chevron","circular_disk","cylinder","sphere","round_co'
      + 'rner_cube_prism"],"type":"string"}},"type":"object"},"chevron":{"descr'
      + 'iption":"chevron","allOf":[{"$ref":"#/definitions/common"},{"descripti'
      + 'on":"chevron specific properties","required":["shape","outside_edge_le'
      + 'ngth","thickness"],"properties":{"thickness":{"description":"thickness'
      + ' in meters","exclusiveMinimum":true,"minimum":0,"type":"number"},"outs'
      + 'ide_edge_length":{"description":"length of the two outer edges in mete'
      + 'rs","exclusiveMinimum":true,"minimum":0,"type":"number"},"shape":{"des'
      + 'cription":"shape identifier","enum":["chevron"],"type":"string"}},"typ'
      + 'e":"object"}],"type":"object"},"round_corner_cube_prism":{"description'
      + '":"round corner cube '
      + 'prism","allOf":[{"$ref":"#/definitions/common"},{"description":"round '
      + 'corner cube prism specific properties","required":["shape","diameter"]'
      + ',"properties":{"diameter":{"description":"diameter in meters","exclusi'
      + 'veMinimum":true,"minimum":0,"type":"number"},"offset":{"description":"'
      + 'offset in meters, e.g. reflector constant '
      + '(optional)","type":"number"},"shape":{"description":"shape identifier"'
      + ',"enum":["round_corner_cube_prism"],"type":"string"}},"type":"object"}'
      + '],"type":"object"}},"properties":{"types":{"uniqueItems":true,"items":'
      + '{"oneOf":[{"$ref":"#/definitions/rectangle"},{"$ref":"#/definitions/ch'
      + 'eckerboard2x2"},{"$ref":"#/definitions/chevron"},{"$ref":"#/definition'
      + 's/circular_disk"},{"$ref":"#/definitions/cylinder"},{"$ref":"#/definit'
      + 'ions/sphere"},{"$ref":"#/definitions/round_corner_cube_prism"}],"type"'
      + ':"object"},"type":"array"}},"required":["types"],"$schema":"http://jso'
      + 'n-schema.org/draft-04/schema#","title":"Control Object '
      + 'Catalog","type":"object"}'
    );

    Example : (''
      + '{"comments":["This file contains a list of control object types (aka. '
      + '''catalog'').","Each type is described by an object,","which must '
      + 'contain at least the following parameters:","  - name: unique '
      + 'identifier of the type","  - shape: one of the following supported '
      + 'shapes:","      - rectangle","      - checkerboard2x2","      - '
      + 'chevron","      - circular_disk","      - cylinder","      - sphere","'
      + '      - round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or '
      + '''diffuse'')"],"types":[{"name":"Rectangle '
      + '60x30","description":"Rectangle (60cm x 30cm)","width":0.3,"length":0.'
      + '6,"shape":"rectangle"},{"name":"Rectangle '
      + '80x40","description":"Rectangle (80cm x 40cm)","width":0.4,"length":0.'
      + '8,"shape":"rectangle"},{"name":"Checkerboard2x2 '
      + '30","description":"Checkerboard (square length: 30cm)","square_length"'
      + ':0.3,"shape":"checkerboard2x2"},{"name":"Checkerboard2x2 '
      + '50","description":"Checkerboard (square length: '
      + '50cm)","square_length":0.5,"shape":"checkerboard2x2"},{"name":"Chevron'
      + ' 24''''/4''''","description":"Chevron (a=24''''; b=4'''')","outside_edge_lengt'
      + 'h":0.6096,"thickness":0.1016,"shape":"chevron"},{"name":"Circular Disk'
      + ' 50","description":" Circular Disk (diameter: 50cm)","diameter":0.5,"s'
      + 'urface_type":"diffuse","shape":"circular_disk"},{"name":"RIEGL flat '
      + 'reflector 50 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","offset":0.0,"diameter":0.05,"surface_type":"re'
      + 'tro_reflective_foil","shape":"circular_disk"},{"name":"RIEGL flat '
      + 'reflector 100 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","offset":0.0,"diameter":0.1,"surface_type":"ret'
      + 'ro_reflective_foil","shape":"circular_disk"},{"name":"RIEGL flat '
      + 'reflector 150 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","offset":0.0,"diameter":0.15,"surface_type":"re'
      + 'tro_reflective_foil","shape":"circular_disk"},{"name":"RIEGL '
      + 'cylindrical reflector 50 mm","description":"cylindrical reflector from'
      + ' retro-reflective foil","height":0.05,"diameter":0.05,"surface_type":"'
      + 'retro_reflective_foil","shape":"cylinder"},{"name":"RIEGL cylindrical '
      + 'reflector 100 mm","description":"cylindrical reflector from '
      + 'retro-reflective foil","height":0.1,"diameter":0.1,"surface_type":"ret'
      + 'ro_reflective_foil","shape":"cylinder"},{"name":"Sphere 200 '
      + 'mm","description":"Sphere (diameter: 200 '
      + 'mm)","diameter":0.2,"shape":"sphere"},{"name":"Corner Cube Prism 50 '
      + 'mm","description":"round corner cube prism","diameter":0.05,"offset":0'
      + '.0,"shape":"round_corner_cube_prism"}]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the control object reference file","$sch'
      + 'ema":"http://json-schema.org/draft-04/schema#","title":"Control Object'
      + ' Reference '
      + 'file","properties":{"reference_file":{"description":"Reference to a '
      + 'control object file","required":["file_uuid","file_path"],"properties"'
      + ':{"file_path":{"description":"Path of the control object file relative'
      + ' to referring '
      + 'file","type":"string"},"file_uuid":{"description":"Control object '
      + 'file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"}},"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"reference_file":{"file_path":"../../../10_CONTROL_OBJECTS/ControlPoi'
      + 'nts.cpx","file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Detection probability as a function of amplitude","typ'
      + 'e":"object","required":["amplitude","detection_probability"],"$schema"'
      + ':"http://json-schema.org/draft-04/schema#","title":"Detection '
      + 'Probability","properties":{"amplitude":{"description":"Amplitude [dB]"'
      + ',"items":{"type":"number"},"type":"array"},"detection_probability":{"d'
      + 'escription":"Detection probability '
      + '[0..1]","items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"detection'
      + '_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the device used to acquire the point clo'
      + 'ud","type":"object","required":["device_type","serial_number"],"$schem'
      + 'a":"http://json-schema.org/draft-04/schema#","title":"Device '
      + 'Information","properties":{"serial_number":{"description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"channel_number":{"description":"Laser '
      + 'channel number (not defined or 0: single channel device)","exclusiveMi'
      + 'nimum":false,"minimum":0,"type":"integer"},"device_build":{"descriptio'
      + 'n":"Device build variant","type":"string"}}}'
    );

    Example : (''
      + '{"serial_number":"S2221234","channel_text":"","device_type":"VZ-400i",'
      + '"device_name":"Scanner 1","channel_number":0,"device_build":""}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scanner device geometry details","type":"object","requ'
      + 'ired":["primary"],"$schema":"http://json-schema.org/draft-04/schema#",'
      + '"title":"Device '
      + 'Geometry","properties":{"primary":{"description":"Primary device '
      + 'geometry structure (mandatory)","required":["ID","content"],"propertie'
      + 's":{"ID":{"description":"Structure identifier","items":{"type":"intege'
      + 'r"},"minItems":2,"type":"array","maxItems":2},"content":{"description"'
      + ':"Internal calibration values","items":{"type":"number"},"type":"array'
      + '"}},"type":"object"},"amu":{"description":"Angle Measurement '
      + 'Unit","properties":{"frameCC":{"description":"Frame Circle Count '
      + '(number of LSBs per full rotation about frame axis)","exclusiveMinimum'
      + '":false,"minimum":0,"type":"number"},"lineCC":{"description":"Line '
      + 'Circle Count (number of LSBs per full rotation about line axis)","excl'
      + 'usiveMinimum":false,"minimum":0,"type":"number"}},"type":"object"},"se'
      + 'condary":{"description":"Additional device geometry structure (optiona'
      + 'l)","required":["ID","content"],"properties":{"ID":{"description":"Str'
      + 'ucture identifier","items":{"type":"integer"},"minItems":2,"type":"arr'
      + 'ay","maxItems":2},"content":{"description":"Internal calibration '
      + 'values","items":{"type":"number"},"type":"array"}},"type":"object"}}}'
    );

    Example : (''
      + '{"primary":{"ID":[4,0],"content":[0]},"amu":{"frameCC":124000,"lineCC"'
      + ':124000},"secondary":{"ID":[91,0],"content":[0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scanner passive channel device geometry details","type'
      + '":"object","required":["primary"],"$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","title":"Device Geometry Passive '
      + 'Channel","properties":{"primary":{"description":"Primary device '
      + 'geometry structure (mandatory)","required":["ID","content"],"propertie'
      + 's":{"ID":{"description":"Structure identifier","items":{"type":"intege'
      + 'r"},"minItems":2,"type":"array","maxItems":2},"content":{"description"'
      + ':"Internal calibration '
      + 'values","items":{"type":"number"},"type":"array"}},"type":"object"}}}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Limits of the measured values output by the device. '
      + 'The limits depend on the device type, measurement program and/or scan '
      + 'pattern.","$schema":"http://json-schema.org/draft-04/schema#","title":'
      + '"Device Output Limits","properties":{"background_radiation_minimum":{"'
      + 'description":"Minimum possible background '
      + 'radiation.","type":"number"},"range_maximum":{"description":"Maximum '
      + 'possible range in meters.","type":"number"},"reflectance_minimum":{"de'
      + 'scription":"Minimum possible reflectance in '
      + 'dB.","type":"number"},"mta_zone_count_maximum":{"description":"Maximum'
      + ' number of MTA '
      + 'zones.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape deviation.","type":"number"},"deviation_minimum":'
      + '{"description":"Minimum possible pulse shape '
      + 'deviation.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in '
      + 'meters.","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'possible amplitude in dB.","type":"number"},"background_radiation_maxi'
      + 'mum":{"description":"Maximum possible background radiation.","type":"n'
      + 'umber"},"amplitude_minimum":{"description":"Minimum possible amplitude'
      + ' in '
      + 'dB.","type":"number"},"reflectance_maximum":{"description":"Maximum '
      + 'possible reflectance in '
      + 'dB.","type":"number"},"echo_count_maximum":{"description":"Maximum '
      + 'number of echoes a laser shot can '
      + 'have.","type":"number"}},"type":"object"}'
    );

    Example : (''
      + '{"range_minimum":2.9,"background_radiation_minimum":0,"deviation_minim'
      + 'um":-1,"range_maximum":10000.0,"reflectance_minimum":-100.0,"mta_zone_'
      + 'count_maximum":7,"background_radiation_maximum":0,"amplitude_minimum":'
      + '0.0,"reflectance_maximum":100.0,"amplitude_maximum":100.0,"deviation_m'
      + 'aximum":32767}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"items":{"required":["device_type","serial_number"],"properties":{"se'
      + 'rial_number":{"description":"Device serial number (e.g. '
      + 'S2221234)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"signed":{"description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly '
      + 'signed.","type":"boolean"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"channel_number":{"description":"Laser '
      + 'channel number (not defined or 0: single channel device)","exclusiveMi'
      + 'nimum":false,"minimum":0,"type":"integer"},"device_build":{"descriptio'
      + 'n":"Device build '
      + 'variant","type":"string"}},"type":"object"},"description":"Details '
      + 'about the devices used to acquire the point cloud (e.g. when merging '
      + 'point clouds of different devices)","$schema":"http://json-schema.org/'
      + 'draft-04/schema#","title":"Devices Information","type":"array"}'
    );

    Example : (''
      + '[{"serial_number":"S2221234","channel_text":"","signed":false,"device_'
      + 'type":"VZ-400i","device_name":"Scanner 1","channel_number":0,"device_b'
      + 'uild":""},{"serial_number":"S2222680","channel_text":"","signed":true,'
      + '"device_type":"VQ-1560i-DW","device_name":"Scanner 2","channel_number"'
      + ':1,"device_build":""},{"serial_number":"S2222680","channel_text":"","s'
      + 'igned":true,"device_type":"VQ-1560i-DW","device_name":"Scanner '
      + '3","channel_number":2,"device_build":""}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Dyntrig","$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#","title":"Dyntrig","properties":{"offset":{"description":"Offset'
      + ' in units of dB, for calculation of '
      + 'line","type":"number"},"post":{"description":"Dyntrig post values","re'
      + 'quired":["nc","a"],"properties":{"a":{"description":"...","minItems":1'
      + ',"items":{"type":"number"},"maxItems":2080,"type":"array"},"nc":{"mini'
      + 'mum":0,"description":"Number of entries","maximum":255,"type":"integer'
      + '"}},"type":"object"},"pre":{"description":"Dyntrig pre values","requir'
      + 'ed":["nc","a"],"properties":{"a":{"description":"...","minItems":1,"it'
      + 'ems":{"type":"number"},"maxItems":2080,"type":"array"},"nc":{"minimum"'
      + ':0,"description":"Number of entries","maximum":255,"type":"integer"}},'
      + '"type":"object"},"scale":{"description":"Scale in units of dB, for '
      + 'calculation of line: line number N=(amplitude-offset)/scale","type":"n'
      + 'umber"},"tab":{"description":"...","minItems":1,"items":{"description"'
      + ':"...","required":["thra1","del1","dec1","thra2","del2","dec2"],"prope'
      + 'rties":{"del1":{"description":"Length of constant post-trigger '
      + 'threshold elevation in units of '
      + 'm","type":"number"},"thra1":{"description":"Post-trigger threshold in '
      + 'units of dB","type":"number"},"dec1":{"description":"Decay of '
      + 'post-trigger threshold after del1 in units of '
      + 'dB/m","type":"number"},"thra2":{"description":"Pre-trigger threshold '
      + 'in units of dB","type":"number"},"dec2":{"description":"Rise of '
      + 'pre-trigger threshold after del2 in units of '
      + 'dB/m","type":"number"},"del2":{"description":"Length of constant '
      + 'pre-trigger threshold elevation in units of '
      + 'm","type":"number"}},"type":"object"},"maxItems":128,"type":"array"}}}'
    );

    Example : (''
      + '{"offset":0.0,"post":{"a":[78,86,126,134,31],"nc":128},"pre":{"a":[78,'
      + '86,126,134,31],"nc":128},"scale":1.0,"tab":[{"del1":0.0,"thra1":0.0,"d'
      + 'ec1":0.0,"thra2":0.0,"dec2":0.0,"del2":0.0}]}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about echo files","type":"object","required":['
      + '"echo_file"],"$schema":"http://json-schema.org/draft-04/schema#","titl'
      + 'e":"Echo Information","properties":{"echo_file":{"required":["file_ext'
      + 'ension"],"properties":{"file_extension":{"description":"Echo file '
      + 'extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object"}}}'
    );

    Example : (''
      + '{"echo_file":{"file_extension":"owp","file_uuid":"26a03615-67c0-4bea-8'
      + 'fe8-c577378fe661"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^[0-9]+$":{"description":"one field per '
      + 'channel, field name is channel '
      + 'index","$ref":"#/definitions/channel"}},"description":"Details for '
      + 'exponential decomposition of full waveform data","definitions":{"chann'
      + 'el":{"required":["delay","scale","parameter"],"properties":{"parameter'
      + '":{"description":"parameters of the syswave exponential sum","required'
      + '":["A","B","gamma","omega"],"properties":{"omega":{"description":"angu'
      + 'lar frequency in Hz","items":{"type":"number"},"type":"array"},"gamma"'
      + ':{"description":"decay in 1/second","items":{"type":"number"},"type":"'
      + 'array"},"B":{"description":"imaginary part of amplitude factor in '
      + 'units of full-scale","items":{"type":"number"},"type":"array"},"A":{"d'
      + 'escription":"real part of amplitude factor in units of full-scale","it'
      + 'ems":{"type":"number"},"type":"array"}},"type":"object"},"a_lin":{"des'
      + 'cription":"relative linear amplitude range [0..1]","maximum":1,"minimu'
      + 'm":0,"exclusiveMinimum":false,"exclusiveMaximum":false,"type":"number"'
      + '},"delay":{"description":"delay calibration in '
      + 'seconds","type":"number"},"scale":{"description":"amplitude calibratio'
      + 'n","type":"number"}},"type":"object"}},"additionalProperties":false,"$'
      + 'schema":"http://json-schema.org/draft-04/schema#","title":"Exponential'
      + ' Decomposition","type":"object"}'
    );

    Example : (''
      + '{"1":{"parameter":{"omega":[352020896.0,3647927552.0,-1977987072.0],"g'
      + 'amma":[-1094726528.0,-769562752.0,-848000064.0],"B":[-3.9,0.0,-0.3],"A'
      + '":[0.9,0.3,-1.3]},"a_lin":0.9,"delay":3.5e-09,"scale":1.0},"0":{"param'
      + 'eter":{"omega":[352020896.0,3647927552.0,-1977987072.0],"gamma":[-1094'
      + '726528.0,-769562752.0,-848000064.0],"B":[-3.9813032150268555,0.0862203'
      + '0913829803,-0.3152860999107361],"A":[0.9772450923919678,0.335433512926'
      + '1017,-1.312678575515747]},"a_lin":0.27,"delay":3.783458418887631e-09,"'
      + 'scale":1.0}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"riegl.gaussian_decomposition contains information '
      + 'relevant for extracting calibrated amplitudes and calibrated ranges '
      + 'from a Gaussian decomposition of full waveform data. This information '
      + 'is contained in a table with five columns. Two columns are to be used '
      + 'as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The '
      + 'other three columns provide the outputs. Amplitude_db gives the '
      + 'calibrated amplitude in the optical regime in decibels. The range '
      + 'offset columns provide additive range offsets, given in units of '
      + 'seconds, for each channel.","type":"object","required":["amplitude_lsb'
      + '_low_power","amplitude_lsb_high_power","amplitude_db","range_offset_se'
      + 'c_low_power","range_offset_sec_high_power"],"$schema":"http://json-sch'
      + 'ema.org/draft-04/schema#","title":"Gaussian Decomposition","properties'
      + '":{"range_offset_sec_high_power":{"items":{"type":"number"},"type":"ar'
      + 'ray"},"range_offset_sec_low_power":{"items":{"type":"number"},"type":"'
      + 'array"},"amplitude_db":{"items":{"type":"number"},"type":"array"},"amp'
      + 'litude_lsb_low_power":{"items":{"type":"number"},"type":"array"},"ampl'
      + 'itude_lsb_high_power":{"items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"range_offset_sec_high_power":[],"range_offset_sec_low_power":[],"amp'
      + 'litude_db":[],"amplitude_lsb_low_power":[],"amplitude_lsb_high_power":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Point cloud georeferencing information","$schema":"htt'
      + 'p://json-schema.org/draft-04/schema#","title":"Geo '
      + 'Tag","properties":{"pose":{"description":"Coordinate Transformation '
      + 'Matrix to transform from File Coordinate System to Global Coordinate '
      + 'Reference System. 4x4 matrix stored as two dimensional array, row '
      + 'major order.","minItems":4,"items":{"description":"rows","minItems":4,'
      + '"items":{"description":"columns","type":"number"},"maxItems":4,"type":'
      + '"array"},"maxItems":4,"type":"array"},"crs":{"description":"Global '
      + 'Coordinate Reference System. Please note that only 3D Cartesian '
      + 'Coordinate Systems are '
      + 'allowed.","properties":{"epsg":{"description":"EPSG '
      + 'code","minimum":0,"type":"integer"},"name":{"description":"Coordinate '
      + 'reference system '
      + 'name","type":"string"},"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"}},"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063'
      + '882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113'
      + '8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0'
      + '.0,0.0,0.0,1.0]],"crs":{"epsg":4978,"name":"WGS84 '
      + 'Geocentric","wkt":"GEOCCS[\"WGS84 Geocentric\",DATUM[\"WGS84\",SPHEROI'
      + 'D[\"WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AU'
      + 'THORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AU'
      + 'THORITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.00000000000000000000,AUTH'
      + 'ORITY[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\'
      + '",NORTH],AUTHORITY[\"EPSG\",\"4978\"]]"}}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Geometric scale factor applied to point coordinates","'
      + '$schema":"http://json-schema.org/draft-04/schema#","exclusiveMinimum":'
      + 'true,"minimum":0,"type":"number"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Parameters used for georeferencing of the point cloud"'
      + ',"$schema":"http://json-schema.org/draft-04/schema#","title":"Georefer'
      + 'encing Parameters","properties":{"trajectory_offsets":{"description":"'
      + 'Correction offsets applied to the trajectory data","properties":{"offs'
      + 'et_yaw":{"description":"[deg]","type":"number"},"offset_roll":{"descri'
      + 'ption":"[deg]","type":"number"},"offset_north":{"description":"[m]","t'
      + 'ype":"number"},"version":{"description":"Meaning of offset values and '
      + 'how to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)","type":"integer"},"offset_time":{"description":"[s]'
      + '","type":"number"},"offset_east":{"description":"[m]","type":"number"}'
      + ',"offset_height":{"description":"[m]","type":"number"},"offset_pitch":'
      + '{"description":"[deg]","type":"number"}},"type":"object"},"socs_to_bod'
      + 'y_matrix":{"description":"Coordinate Transformation Matrix to '
      + 'transform from Scanner''s Own Coordinate System to Body Coordinate '
      + 'System. 4x4 matrix stored as two dimensional array, row major order.",'
      + '"minItems":4,"items":{"description":"rows","minItems":4,"items":{"desc'
      + 'ription":"columns","type":"number"},"maxItems":4,"type":"array"},"maxI'
      + 'tems":4,"type":"array"},"body_coordinate_system_type":{"description":"'
      + 'BODY coordinate frame (NED: North-East-Down, ENU: East-North-Up), '
      + 'default: NED","enum":["NED","ENU"],"type":"string"},"socs_to_rocs_matr'
      + 'ix":{"description":"Coordinate Transformation Matrix to transform from'
      + ' Scanner''s Own Coordinate System to Record Coordinate System. 4x4 '
      + 'matrix stored as two dimensional array, row major order.","minItems":4'
      + ',"items":{"description":"rows","minItems":4,"items":{"description":"co'
      + 'lumns","type":"number"},"maxItems":4,"type":"array"},"maxItems":4,"typ'
      + 'e":"array"},"trajectory_file":{"description":"Trajectory data used for'
      + ' georeferencing of the point cloud","required":["file_extension"],"pro'
      + 'perties":{"file_extension":{"description":"Trajectory file extension, '
      + 'without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"}},"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"trajectory_offsets":{"offset_yaw":-0.45,"offset_roll":0.03,"offset_n'
      + 'orth":0.07,"version":0,"offset_time":18.007,"offset_east":0.15,"offset'
      + '_height":-0.2,"offset_pitch":0.01},"socs_to_body_matrix":[[-0.26982777'
      + '6749716,-0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-'
      + '0.20260517250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.75086'
      + '84796801,0.0],[0.0,0.0,0.0,1.0]],"body_coordinate_system_type":"NED","'
      + 'trajectory_file":{"file_extension":"pofx","file_uuid":"93a03615-66c0-4'
      + 'bea-8ff8-c577378fe660"}}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^-?[0-9]+$":{"description":"One field per item,'
      + ' field name is item id, field value is item '
      + 'name","type":"string"}},"description":"Map of item names","additionalP'
      + 'roperties":false,"$schema":"http://json-schema.org/draft-04/schema#","'
      + 'title":"Item Names","type":"object"}'
    );

    Example : (''
      + '{"1":"Name of item with id 1","2":"Name of item with id 2","47":"Name '
      + 'of item with id 47","-1":"Name of item with id -1"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a feature and holds a list of license keys, where the field'
      + ' name is the feature name.","items":{"description":"License key '
      + '(example: ''46AE032A - 39882AC4 - 9EC0A184 - 6F163D73'')","type":"string'
      + '"},"minItems":1,"type":"array"}},"description":"License keys for '
      + 'software features","additionalProperties":false,"$schema":"http://json'
      + '-schema.org/draft-04/schema#","title":"Software License '
      + 'Keys","type":"object"}'
    );

    Example : (''
      + '{"MTA resolution":["468E020A - 39A922E4 - B681A184 - 673E3D72"],"Full '
      + 'Waveform Analysis Topography with GPU support":["8AB44126 - 23B92250 -'
      + ' 16E2689F - 34EF7E7B"],"Georeferencing":["46AE032A - 39882AC4 - '
      + '9EC0A184 - 6F163D73"],"Full Waveform Analysis Topography":["0FD5FF07 -'
      + ' 011A1255 - 9F76CACA - 8D2ED557"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Parameters for MTA processing","$schema":"http://json-'
      + 'schema.org/draft-04/schema#","title":"MTA '
      + 'Settings","properties":{"zone_width":{"description":"Width of a MTA '
      + 'zone in meter.","minimum":0,"type":"number"},"zone_count":{"descriptio'
      + 'n":"Maximum number of MTA zones.","maximum":255,"minimum":0,"type":"in'
      + 'teger"},"modulation_depth":{"description":"Depth of pulse position '
      + 'modulation in meter.","minimum":0,"type":"number"}},"type":"object"}'
    );

    Example : (''
      + '{"zone_width":149.896225,"zone_count":23,"modulation_depth":9.368514}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Lookup table for range correction based on raw range",'
      + '"type":"object","required":["delta","content"],"$schema":"http://json-'
      + 'schema.org/draft-04/schema#","title":"Near Range Correction '
      + 'Table","properties":{"content":{"description":"Correction value [m] to'
      + ' be added to the raw range","items":{"type":"number"},"minItems":1,"ty'
      + 'pe":"array","maxItems":2000},"delta":{"description":"Delta between '
      + 'table entries [m], first entry is at range = 0 m","type":"number"}}}'
    );

    Example : (''
      + '{"content":[0.0],"delta":0.512}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Standard deviation for range and amplitude as a '
      + 'function of amplitude","type":"object","required":["amplitude","range_'
      + 'sigma","amplitude_sigma"],"$schema":"http://json-schema.org/draft-04/s'
      + 'chema#","title":"Noise '
      + 'Estimates","properties":{"amplitude":{"description":"Amplitude [dB]","'
      + 'items":{"type":"number"},"type":"array"},"range_sigma":{"description":'
      + '"Sigma range [m]","items":{"type":"number"},"type":"array"},"amplitude'
      + '_sigma":{"description":"Sigma amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"range_sig'
      + 'ma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,0.016,0.014'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Notch filter parameters for window glass echoes","type'
      + '":"object","required":["range_minimum","range_maximum","amplitude_maxi'
      + 'mum"],"$schema":"http://json-schema.org/draft-04/schema#","title":"Not'
      + 'ch Filter","properties":{"range_minimum":{"description":"Minimum range'
      + ' [m]","type":"number"},"amplitude_maximum":{"minimum":0,"description":'
      + '"Maximum amplitude '
      + '[dB]","type":"number"},"range_maximum":{"description":"Maximum range '
      + '[m]","type":"number"}}}'
    );

    Example : (''
      + '{"range_minimum":-0.5,"amplitude_maximum":18.0,"range_maximum":0.2}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the pixels contained in the '
      + 'file","definitions":{"pixel_size":{"description":"Size of '
      + 'pixels.","minItems":2,"items":{"description":"Length of pixel edge [m]'
      + '.","minimum":0,"type":"number"},"maxItems":2,"type":"array"}},"propert'
      + 'ies":{"size":{"description":"Size of pixels in file coordinate system.'
      + '","$ref":"#/definitions/pixel_size"},"size_llcs":{"description":"Size '
      + 'of pixels in a locally levelled cartesian coordinate system (xy). This'
      + ' is only used for pixels based on a map projection.","$ref":"#/definit'
      + 'ions/pixel_size"}},"required":["size"],"$schema":"http://json-schema.o'
      + 'rg/draft-04/schema#","title":"Pixel Information","type":"object"}'
    );

    Example : (''
      + '{"size":[0.5971642834779395,0.5971642834779395],"size_llcs":[0.5156575'
      + '252891171,0.5130835356683303]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the plane patch matching '
      + 'process","definitions":{"file_reference":{"description":"Reference to '
      + 'a plane patch file","required":["file_uuid","file_path"],"properties":'
      + '{"file_path":{"description":"Path of the plane patch file relative to '
      + 'the match file","type":"string"},"file_uuid":{"description":"Plane '
      + 'patch file''s Universally Unique Identifier (RFC 4122)","type":"string"'
      + '}},"type":"object"}},"properties":{"plane_patch_file_two":{"descriptio'
      + 'n":"Reference to the plane patch file two","$ref":"#/definitions/file_'
      + 'reference"},"plane_patch_file_one":{"description":"Reference to the '
      + 'plane patch file one","$ref":"#/definitions/file_reference"}},"require'
      + 'd":["plane_patch_file_one","plane_patch_file_two"],"$schema":"http://j'
      + 'son-schema.org/draft-04/schema#","title":"Plane Patch '
      + 'Matching","type":"object"}'
    );

    Example : (''
      + '{"plane_patch_file_two":{"file_path":"project.ptch","file_uuid":"fa47d'
      + '509-a64e-49ce-8b14-ff3130fbefa9"},"plane_patch_file_one":{"file_path":'
      + '"Record009_Line001/191025_121410_Scanner_1.ptch","file_uuid":"810f5d57'
      + '-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Statistics about plane patches found by plane patch ex'
      + 'tractor","$schema":"http://json-schema.org/draft-04/schema#","title":"'
      + 'Plane Patch Statistics","properties":{"total_area":{"description":"sum'
      + ' of all plane patch areas [m\u00b2]","type":"number"},"total_horizonta'
      + 'l_area":{"description":"sum of all plane patch areas projected to '
      + 'horizontal plane [m\u00b2]","type":"number"}},"type":"object"}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Settings and classes for plane slope classification","'
      + 'definitions":{"method-1":{"description":"Classification method 1","req'
      + 'uired":["plane_classification_method","maximum_inclination_angle_horiz'
      + 'ontal"],"properties":{"maximum_inclination_angle_horizontal":{"descrip'
      + 'tion":"maximum inclination angle of horizontal plane patches [deg]","m'
      + 'aximum":360.0,"minimum":-360.0,"type":"number"},"plane_classification_'
      + 'method":{"description":"method ID (=1)","maximum":1,"minimum":1,"type"'
      + ':"integer"}},"type":"object"},"method-2":{"description":"Classificatio'
      + 'n method 2","required":["plane_classification_method","sloping_plane_c'
      + 'lasses_minimum_angle","sloping_plane_classes_maximum_angle"],"properti'
      + 'es":{"sloping_plane_classes_maximum_angle":{"description":"maximum '
      + 'inclination angle of sloping plane patches [deg]","maximum":360.0,"min'
      + 'imum":-360.0,"type":"number"},"sloping_plane_classes_minimum_angle":{"'
      + 'description":"minimum inclination angle of sloping plane patches [deg]'
      + '","maximum":360.0,"minimum":-360.0,"type":"number"},"plane_classificat'
      + 'ion_method":{"description":"method ID (=2)","maximum":2,"minimum":2,"t'
      + 'ype":"integer"}},"type":"object"}},"properties":{"classes":{"patternPr'
      + 'operties":{"^[0-9]+$":{"description":"one field per class, field name '
      + 'is class number, field value is class '
      + 'name","type":"string"}},"description":"Class definition table","additi'
      + 'onalProperties":false,"type":"object"},"settings":{"oneOf":[{"$ref":"#'
      + '/definitions/method-1"},{"$ref":"#/definitions/method-2"}],"descriptio'
      + 'n":"Classification settings, details see documentation of rdbplanes","'
      + 'type":"object"}},"required":["settings","classes"],"$schema":"http://j'
      + 'son-schema.org/draft-04/schema#","title":"Plane Slope Class '
      + 'Info","type":"object"}'
    );

    Example : (''
      + '{"classes":{"10":"sloping, pointing down and east","12":"sloping, '
      + 'pointing down and north","11":"sloping, pointing down and '
      + 'south","9":"vertical, pointing west","4":"sloping, pointing up and '
      + 'north","3":"sloping, pointing up and south","2":"sloping, pointing up '
      + 'and east","1":"horizontal, pointing up","14":"horizontal, pointing '
      + 'down","13":"sloping, pointing down and west","8":"vertical, pointing '
      + 'north","7":"vertical, pointing south","6":"vertical, pointing '
      + 'east","5":"sloping, pointing up and west"},"settings":{"sloping_plane_'
      + 'classes_maximum_angle":70.0,"sloping_plane_classes_minimum_angle":10.0'
      + ',"plane_classification_method":2}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a point attribute group and holds a list of point '
      + 'attributes, where the field name is the group '
      + 'name.","items":{"description":"Point attribute full name or name '
      + 'pattern (perl regular expression syntax)","type":"string"},"minItems":'
      + '1,"type":"array"}},"description":"Grouping and sorting of point '
      + 'attributes for visualization purposes","additionalProperties":false,"$'
      + 'schema":"http://json-schema.org/draft-04/schema#","title":"Point '
      + 'Attribute Groups","type":"object"}'
    );

    Example : (''
      + '{"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"],"Primary'
      + ' Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]'
      + ',"Coordinates/Vectors":["riegl.xyz","riegl.range","riegl.theta","riegl'
      + '.phi"],"Other Attributes":["riegl.selected","riegl.visible"],"Time":["'
      + 'riegl.timestamp"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about point cloud files","$schema":"http://jso'
      + 'n-schema.org/draft-04/schema#","title":"Point Cloud '
      + 'Information","properties":{"project":{"description":"Project name","ty'
      + 'pe":"string"},"comments":{"description":"Comments","type":"string"},"f'
      + 'ield_of_application":{"description":"Field of application","enum":["un'
      + 'known","SLS","TLS","KLS","MLS","ULS","ALS","BLS","ILS"],"type":"string'
      + '"}},"type":"object"}'
    );

    Example : (''
      + '{"project":"Campaign 4","comments":"Line '
      + '3","field_of_application":"ALS"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Estimated position and orientation information as '
      + 'measured by GNSS, IMU or inclination sensors","type":"object","require'
      + 'd":["orientation"],"$schema":"http://json-schema.org/draft-04/schema#"'
      + ',"title":"Pose Estimation","properties":{"barometric_height_amsl":{"de'
      + 'scription":"Altitude determined based on the atmospheric pressure '
      + 'according to the standard atmosphere laws '
      + '[m].","type":"number"},"position":{"description":"Position coordinates'
      + ' and position accuracy values as measured by GNSS in the specified '
      + 'Coordinate Reference System (CRS)","required":["coordinate_1","coordin'
      + 'ate_2","coordinate_3","horizontal_accuracy","vertical_accuracy","crs"]'
      + ',"properties":{"vertical_accuracy":{"description":"Vertical accuracy ['
      + 'm]","exclusiveMinimum":true,"minimum":0,"type":"number"},"crs":{"descr'
      + 'iption":"Global Coordinate Reference '
      + 'System","required":["epsg"],"properties":{"epsg":{"description":"EPSG '
      + 'code","minimum":0,"type":"integer"},"wkt":{"description":"\"Well-Known'
      + ' Text\" string, OGC WKT dialect (see http://www.opengeospatial.org/sta'
      + 'ndards/wkt-crs)","type":"string"}},"type":"object"},"coordinate_2":{"d'
      + 'escription":"Coordinate 2 as defined by axis 2 of the specified CRS '
      + '(e.g., Y, '
      + 'Longitude)","type":"number"},"coordinate_3":{"description":"Coordinate'
      + ' 3 as defined by axis 3 of the specified CRS (e.g., Z, '
      + 'Altitude)","type":"number"},"coordinate_1":{"description":"Coordinate '
      + '1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)","type'
      + '":"number"},"horizontal_accuracy":{"description":"Horizontal accuracy '
      + '[m]","exclusiveMinimum":true,"minimum":0,"type":"number"}},"type":"obj'
      + 'ect"},"orientation":{"description":"Orientation values and orientation'
      + ' accuracies, measured with IMU or inclination sensors.","required":["r'
      + 'oll","pitch","yaw","roll_accuracy","pitch_accuracy","yaw_accuracy"],"p'
      + 'roperties":{"pitch_accuracy":{"description":"Pitch angle accuracy [deg'
      + ']","exclusiveMinimum":true,"minimum":0,"type":"number"},"roll_accuracy'
      + '":{"description":"Roll angle accuracy [deg]","exclusiveMinimum":true,"'
      + 'minimum":0,"type":"number"},"yaw_accuracy":{"description":"Yaw angle '
      + 'accuracy [deg]","exclusiveMinimum":true,"minimum":0,"type":"number"},"'
      + 'yaw":{"description":"Yaw angle about scanner Z-axis [deg]","maximum":3'
      + '60,"minimum":-360,"type":"number"},"roll":{"description":"Roll angle '
      + 'about scanner X-axis [deg]","maximum":360,"minimum":-360,"type":"numbe'
      + 'r"},"pitch":{"description":"Pitch angle about scanner Y-axis [deg]","m'
      + 'aximum":360,"minimum":-360,"type":"number"}},"type":"object"}}}'
    );

    Example : (''
      + '{"barometric_height_amsl":386.7457796227932,"position":{"vertical_accu'
      + 'racy":1.3314999341964722,"crs":{"epsg":4979,"wkt":"GEOGCS[\"WGS84 / Ge'
      + 'ographic\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.25722356'
      + '3,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\'
      + '"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"D'
      + 'egree\",0.01745329251994329547,AUTHORITY[\"EPSG\",\"9102\"]],AXIS[\"La'
      + 'titude\",NORTH],AXIS[\"Longitude\",EAST],AUTHORITY[\"EPSG\",\"4979\"]]'
      + '"},"coordinate_2":15.645033406,"coordinate_3":362.7124938964844,"coord'
      + 'inate_1":48.655799473,"horizontal_accuracy":0.810699999332428},"orient'
      + 'ation":{"pitch_accuracy":0.009433783936875745,"roll_accuracy":0.009433'
      + '783936875745,"yaw_accuracy":1.0094337839368757,"yaw":101.8729363029204'
      + '5,"roll":3.14743073066123,"pitch":1.509153024827064}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details on position and orientation sensors","definiti'
      + 'ons":{"vector":{"minItems":3,"items":{"description":"Index 0=X, 1=Y, '
      + '2=Z component","type":"number"},"maxItems":3,"type":"array"}},"propert'
      + 'ies":{"magnetic_field_sensor":{"description":"Magnetic Field Sensor de'
      + 'tails","required":["unit","x_axis","y_axis","z_axis","offset","fixed",'
      + '"relative_nonlinearity"],"properties":{"x_axis":{"description":"Sensit'
      + 'ive X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"unit":{"description":"Unit of raw '
      + 'data and calibration values, 1 LSB in nT","exclusiveMinimum":true,"min'
      + 'imum":0,"type":"number"},"relative_nonlinearity":{"description":"Relat'
      + 'ive nonlinearity, dimensionless","$ref":"#/definitions/vector"},"offse'
      + 't":{"description":"Value to be subtracted from raw measurement values"'
      + ',"$ref":"#/definitions/vector"},"z_axis":{"description":"Sensitive Z '
      + 'axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"fixed":{"description":"Distortion '
      + 'of magnetic field caused by non-rotating scanner part","$ref":"#/defin'
      + 'itions/vector"}},"type":"object"},"accelerometer":{"description":"Acce'
      + 'lerometer details","required":["unit","x_axis","y_axis","z_axis","offs'
      + 'et","origin","relative_nonlinearity"],"properties":{"x_axis":{"descrip'
      + 'tion":"Sensitive X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"},"unit":{"description":"Unit of raw '
      + 'data and calibration values, 1 LSB in 9.81 m/s\u00b2","exclusiveMinimu'
      + 'm":true,"minimum":0,"type":"number"},"relative_nonlinearity":{"descrip'
      + 'tion":"Relative nonlinearity, dimensionless","$ref":"#/definitions/vec'
      + 'tor"},"offset":{"description":"Value to be subtracted from raw '
      + 'measurement values","$ref":"#/definitions/vector"},"z_axis":{"descript'
      + 'ion":"Sensitive Z axis of sensor at frame angle = 0","$ref":"#/definit'
      + 'ions/vector"}},"type":"object"},"gyroscope":{"description":"Gyroscope '
      + 'details","required":["unit","x_axis","y_axis","z_axis","offset","origi'
      + 'n","relative_nonlinearity"],"properties":{"x_axis":{"description":"Sen'
      + 'sitive X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"},"unit":{"description":"Unit of raw '
      + 'data and calibration values, 1 LSB in rad/s","exclusiveMinimum":true,"'
      + 'minimum":0,"type":"number"},"relative_nonlinearity":{"description":"Re'
      + 'lative nonlinearity, dimensionless","$ref":"#/definitions/vector"},"of'
      + 'fset":{"description":"Value to be subtracted from raw measurement valu'
      + 'es","$ref":"#/definitions/vector"},"z_axis":{"description":"Sensitive '
      + 'Z axis of sensor at frame angle = 0","$ref":"#/definitions/vector"}},"'
      + 'type":"object"}},"required":["gyroscope","accelerometer","magnetic_fie'
      + 'ld_sensor"],"$schema":"http://json-schema.org/draft-04/schema#","title'
      + '":"Pose Sensors","type":"object"}'
    );

    Example : (''
      + '{"magnetic_field_sensor":{"x_axis":[-0.011162743903696537,-2.315962774'
      + '446234e-05,0.00016818844596855342],"y_axis":[0.00027888521435670555,-0'
      + '.011427424848079681,-5.204829722060822e-05],"unit":91.74311828613281,"'
      + 'relative_nonlinearity":[0.0,0.0,0.0],"offset":[-23812.052734375,5606.5'
      + '7666015625,2493.28125],"z_axis":[0.00041987866279669106,7.876977906562'
      + '388e-05,0.011407104320824146],"fixed":[-1576.010498046875,1596.0817871'
      + '09375,0.0]},"accelerometer":{"x_axis":[-15008.123046875,56.95639038085'
      + '9375,-60.5175666809082],"y_axis":[-7.027288913726807,-44.1233367919921'
      + '9,14952.3701171875],"origin":[0.026900000870227814,-0.0399999991059303'
      + '3,-0.08950000256299973],"unit":6.666666740784422e-05,"relative_nonline'
      + 'arity":[0.0,0.0,0.0],"offset":[-733.3636474609375,58.969032287597656,1'
      + '060.2550048828125],"z_axis":[1.639882206916809,15166.744140625,-116.99'
      + '742889404297]},"gyroscope":{"x_axis":[-121.195556640625,0.821971416473'
      + '3887,0.2313031703233719],"y_axis":[-0.440765917301178,-0.7897399663925'
      + '171,119.5894775390625],"origin":[0.026900000870227814,-0.0399999991059'
      + '3033,-0.08950000256299973],"unit":0.00014544410805683583,"relative_non'
      + 'linearity":[2.888176311444113e-07,1.06274164579645e-07,-1.718629508063'
      + '4935e-39],"offset":[-50.92609786987305,146.15643310546875,62.432727813'
      + '7207],"z_axis":[0.555869996547699,119.22135162353516,0.467585027217865'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Laser pulse position modulation used for MTA resolutio'
      + 'n","type":"object","required":["length","num_mod_ampl","pulse_interval'
      + '"],"$schema":"http://json-schema.org/draft-04/schema#","title":"Pulse '
      + 'Position '
      + 'Modulation","properties":{"code_phase_mode":{"description":"0: no '
      + 'synchronization, 1: toggle between 2 phases, 2: increment with phase_i'
      + 'ncrement","maximum":255,"minimum":0,"type":"integer"},"length":{"descr'
      + 'iption":"Length of code","maximum":255,"minimum":0,"type":"integer"},"'
      + 'pulse_interval":{"description":"Explicit table of the pulse position '
      + 'modulation used for MTA resolution. Table gives times between '
      + 'successive laser pulses in seconds.","items":{"minimum":0,"type":"numb'
      + 'er"},"type":"array"},"phase_step":{"description":"Step width in phase '
      + 'of modulation code from line to line","maximum":255,"minimum":0,"type"'
      + ':"integer"},"num_mod_ampl":{"description":"Number of different '
      + 'modulation amplitudes (2: binary '
      + 'modulation)","maximum":255,"minimum":0,"type":"integer"}}}'
    );

    Example : (''
      + '{"code_phase_mode":2,"length":31,"pulse_interval":[2.759375e-06,2.7593'
      + '75e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-0'
      + '6,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.7'
      + '59375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875'
      + 'e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,'
      + '2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821'
      + '875e-06,2.759375e-06,2.821875e-06],"phase_step":5,"num_mod_ampl":2}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Statistics about target distance wrt. SOCS origin","ty'
      + 'pe":"object","required":["minimum","average","maximum","std_dev"],"$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","title":"Range '
      + 'Statistics","properties":{"minimum":{"description":"Minimum '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"},"maximum":{"description":"Maximum '
      + 'value","type":"number"},"average":{"description":"Average '
      + 'value","type":"number"}}}'
    );

    Example : (''
      + '{"minimum":0.919,"std_dev":24.349,"maximum":574.35,"average":15.49738}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Receiver '
      + 'Internals","definitions":{"fp":{"description":"Fingerprint values","re'
      + 'quired":["s","w"],"properties":{"s":{"minItems":1,"items":{"minItems":'
      + '1,"items":{"type":"number"},"maxItems":4096,"type":"array"},"maxItems"'
      + ':256,"type":"array"},"w":{"minItems":1,"items":{"minItems":5,"items":{'
      + '"type":"number"},"maxItems":5,"type":"array"},"maxItems":256,"type":"a'
      + 'rray"}},"type":"object"},"fp_table_row":{"minItems":1,"items":{"type":'
      + '"number"},"maxItems":2048,"type":"array"},"fp_table":{"properties":{"t'
      + 'v":{"minItems":1,"items":{"oneOf":[{"$ref":"#/definitions/fp_table_row'
      + '"},{"type":"number"}]},"maxItems":2048,"type":"array"},"ch":{"min":0,"'
      + 'description":"channel '
      + 'number","type":"integer","max":255},"tc":{"min":0,"description":"table'
      + ' data type '
      + 'code","type":"integer","max":255},"nx":{"min":1,"description":"number '
      + 'of x entries","type":"integer","max":2048},"ny":{"min":1,"description"'
      + ':"number of y entries","type":"integer","max":2048}},"required":["ch",'
      + '"tc","nx","ny","tv"],"desription":"scanner internal data","type":"obje'
      + 'ct"}},"properties":{"sr":{"minimum":0,"exclusiveMinimum":true,"descrip'
      + 'tion":"Sample rate [Hz]","type":"number"},"mw":{"description":"Maximum'
      + ' weight","minimum":0,"exclusiveMinimum":true,"maximum":4095,"type":"nu'
      + 'mber"},"tbl":{"minItems":1,"items":{"$ref":"#/definitions/fp_table"},"'
      + 'description":"various internal '
      + 'data","type":"array"},"ex":{"description":"DEPRECATED, use '
      + '''riegl.exponential_decomposition'' '
      + 'instead","type":"object"},"a":{"description":"Amplitude [dB]","minItem'
      + 's":1,"items":{"type":"number"},"maxItems":256,"type":"array"},"si":{"m'
      + 'inimum":0,"description":"Start index (hw_start)","maximum":255,"type":'
      + '"number"},"ns":{"minimum":0,"description":"Number of samples","maximum'
      + '":4095,"type":"integer"},"t":{"patternProperties":{"^[0-9]+$":{"descri'
      + 'ption":"one field per channel, field name is channel index","$ref":"#/'
      + 'definitions/fp"}},"additionalProperties":false,"type":"object"},"nt":{'
      + '"minimum":0,"description":"Number of traces","maximum":255,"type":"int'
      + 'eger"}},"$schema":"http://json-schema.org/draft-04/schema#","title":"R'
      + 'eceiver Internals","type":"object"}'
    );

    Example : (''
      + '{"sr":7959997000.0,"mw":31,"tbl":[{"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,'
      + '5.5]],"ch":0,"tc":1,"nx":5,"ny":2}],"a":[-1.55],"si":48,"ns":400,"t":{'
      + '"1":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134,31],[78,86,126,'
      + '134,31]]},"0":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134,31],['
      + '78,86,126,134,31]]}},"nt":128}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Lookup table for reflectance calculation based on '
      + 'amplitude and range","type":"object","required":["delta","content"],"$'
      + 'schema":"http://json-schema.org/draft-04/schema#","title":"Reflectance'
      + ' Calculation Table","properties":{"content":{"description":"Correction'
      + ' value [dB] to be added to the amplitude","items":{"type":"number"},"m'
      + 'inItems":1,"type":"array","maxItems":2000},"delta":{"description":"Del'
      + 'ta between table entries [m], first entry is at range = 0 '
      + 'm","type":"number"}}}'
    );

    Example : (''
      + '{"content":[-33.01],"delta":0.150918}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Range-dependent and scan-angle-dependent correction of'
      + ' reflectance reading","type":"object","required":["ranges_m","line_ang'
      + 'les_deg","reflectance_correction_db"],"$schema":"http://json-schema.or'
      + 'g/draft-04/schema#","title":"Near-range reflectance correction","prope'
      + 'rties":{"reflectance_correction_db":{"description":"Near range '
      + 'reflectance correction in dB as a function of range over '
      + 'angle","items":{"description":"rows (each array corresponds to a '
      + 'range)","items":{"description":"columns (each value corresponds to an '
      + 'angle)","type":"number"},"type":"array"},"type":"array"},"line_angles_'
      + 'deg":{"description":"Angle [deg]","items":{"type":"number"},"type":"ar'
      + 'ray"},"ranges_m":{"description":"Range '
      + '[m]","items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.'
      + '01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0'
      + '.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],"li'
      + 'ne_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],"ranges_m":[0'
      + '.0,1.0,2.0,3.0]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scan pattern description","$schema":"http://json-schem'
      + 'a.org/draft-04/schema#","title":"Scan '
      + 'Pattern","definitions":{"program":{"description":"Measurement '
      + 'program","required":["name"],"properties":{"name":{"description":"Name'
      + ' of measurement '
      + 'program","type":"string"},"laser_prr":{"description":"Laser Pulse '
      + 'Repetition Rate [Hz]","exclusiveMinimum":false,"minimum":0,"type":"num'
      + 'ber"}},"type":"object"}},"properties":{"rectangular":{"description":"R'
      + 'ectangular Field Of View Scan Pattern","required":["phi_start","phi_st'
      + 'op","phi_increment","theta_start","theta_stop","theta_increment"],"pro'
      + 'perties":{"phi_start":{"description":"Start phi angle in SOCS [deg]","'
      + 'maximum":360.0,"minimum":0.0,"type":"number"},"phi_increment":{"descri'
      + 'ption":"Increment of phi angle in SOCS [deg]","maximum":90.0,"minimum"'
      + ':0.0,"type":"number"},"theta_start":{"description":"Start theta angle '
      + 'in SOCS [deg]","maximum":180.0,"minimum":0.0,"type":"number"},"phi_sto'
      + 'p":{"description":"Stop phi angle in SOCS [deg]","maximum":720.0,"mini'
      + 'mum":0.0,"type":"number"},"theta_increment":{"description":"Increment '
      + 'of theta angle in SOCS [deg]","maximum":90.0,"minimum":0.0,"type":"num'
      + 'ber"},"program":{"$ref":"#/definitions/program"},"theta_stop":{"descri'
      + 'ption":"Stop theta angle in SOCS [deg]","maximum":180.0,"minimum":0.0,'
      + '"type":"number"}},"type":"object"},"line":{"description":"Line Scan Pa'
      + 'ttern","required":["start","stop","increment"],"properties":{"program"'
      + ':{"$ref":"#/definitions/program"},"increment":{"description":"Incremen'
      + 't of angle in SOCS [deg]","maximum":90.0,"minimum":0.0,"type":"number"'
      + '},"start":{"description":"Start angle in SOCS [deg]","maximum":360.0,"'
      + 'minimum":0.0,"type":"number"},"stop":{"description":"Stop angle in '
      + 'SOCS [deg]","maximum":720.0,"minimum":0.0,"type":"number"}},"type":"ob'
      + 'ject"},"segments":{"description":"Segmented Line Scan Pattern","requir'
      + 'ed":["list"],"properties":{"program":{"$ref":"#/definitions/program"},'
      + '"list":{"items":{"description":"Line Scan Segment","required":["start"'
      + ',"stop","increment"],"properties":{"increment":{"description":"Increme'
      + 'nt of angle in SOCS [deg]","maximum":90.0,"minimum":0.0,"type":"number'
      + '"},"start":{"description":"Start angle in SOCS [deg]","maximum":360.0,'
      + '"minimum":0.0,"type":"number"},"stop":{"description":"Stop angle in '
      + 'SOCS [deg]","maximum":720.0,"minimum":0.0,"type":"number"}},"type":"ob'
      + 'ject"},"type":"array"}},"type":"object"}}}'
    );

    Example : (''
      + '{"rectangular":{"phi_start":45.0,"phi_increment":0.04,"theta_start":30'
      + '.0,"phi_stop":270.0,"theta_increment":0.04,"program":{"name":"High '
      + 'Speed","laser_prr":100000.0},"theta_stop":130.0}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about laser shot files","$schema":"http://json'
      + '-schema.org/draft-04/schema#","title":"Shot Information","properties":'
      + '{"shot_file":{"required":["file_extension"],"properties":{"file_extens'
      + 'ion":{"description":"Shot file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"}},"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"shot_file":{"file_extension":"sodx","file_uuid":"26a00815-67c0-4bff-'
      + '8fe8-c577378fe663"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Point filters applied in addition to the '
      + 'application-defined filters","type":"object","required":["activated","'
      + 'filters"],"$schema":"http://json-schema.org/draft-04/schema#","title":'
      + '"Stored filters","properties":{"activated":{"description":"Apply '
      + '(''true'') or ignore (''false'') all '
      + 'filters","type":"boolean"},"filters":{"description":"List of point '
      + 'filters","items":{"description":"Point filter definition","required":['
      + '"activated","title","description","filter"],"properties":{"activated":'
      + '{"description":"Apply (''true'') or ignore (''false'') this '
      + 'filter","type":"boolean"},"description":{"description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)","type":"string"},"filter":{"description":"The RDB filter '
      + 'string to apply (e.g. when reading points or index), details see '
      + 'documentation of function '
      + 'select()","type":"string"},"title":{"description":"A short filter '
      + 'title (e.g. for display in a selection '
      + 'list)","type":"string"}},"type":"object"},"type":"array"}}}'
    );

    Example : (''
      + '{"activated":true,"filters":[{"activated":false,"description":"Ignore '
      + 'points with uncertain MTA zone '
      + 'assignment","filter":"riegl.mta_uncertain_point == 0","title":"Ignore '
      + 'uncertain points from MTA '
      + 'resolution"},{"activated":false,"description":"Ignore points with an '
      + 'echo signal amplitude below the dynamic '
      + 'trigger","filter":"riegl.dyntrig_uncertain_point == 0","title":"Ignore'
      + ' points below dynamic trigger '
      + 'level"},{"activated":false,"description":"Ignore points that are '
      + 'outside the outer AABB in '
      + 'BOCS","filter":"riegl.point_outside_aabb_bocs == 0","title":"Ignore '
      + 'points outside outer AABB"},{"activated":false,"description":"Ignore '
      + 'points that are inside the inner AABB in '
      + 'BOCS","filter":"riegl.point_inside_aabb_bocs == 0","title":"Ignore '
      + 'points inside inner AABB"}]}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details of major system components like lidar sensors,'
      + ' cameras and navigation devices","type":"object","required":["$class",'
      + '"version","author","timestamp","system"],"$schema":"http://json-schema'
      + '.org/draft-04/schema#","title":"System '
      + 'Description","properties":{"system":{"description":"The actual system '
      + 'description, details see documentation of RIEGL System '
      + 'Description","type":"object"},"author":{"description":"Name of the '
      + 'author that created the '
      + 'document","type":"string"},"$class":{"description":"Object class name"'
      + ',"enum":["Document"],"type":"string"},"version":{"description":"Docume'
      + 'nt format version","type":"string"},"timestamp":{"description":"Date '
      + 'and time of creation (e.g. '
      + '2019-06-19T13:32:10+02:00)","type":"string"}}}'
    );

    Example : (''
      + '{"system":{"details":"see documentation of RIEGL System '
      + 'Description"},"author":"RIEGL LMS GmbH, Austria","$class":"Document","'
      + 'version":"1.2.1","timestamp":"2022-09-30T11:56:26+00:00"}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Conversion of background radiation raw values to '
      + 'temperatures in \u00b0C","definitions":{"conversion_table":{"required"'
      + ':["value","temperature"],"properties":{"value":{"description":"LSB [1]'
      + '","items":{"type":"number"},"type":"array"},"temperature":{"descriptio'
      + 'n":"Temperature [\u00b0C]","items":{"type":"number"},"type":"array"}},'
      + '"type":"object"}},"properties":{"InGaAs":{"description":"Conversion '
      + 'table for InGaAs channel","$ref":"#/definitions/conversion_table"},"In'
      + 'GaAs_Si_Difference":{"description":"Conversion table for InGaAs - Si d'
      + 'ifference","$ref":"#/definitions/conversion_table"},"Si":{"description'
      + '":"Conversion table for Si channel","$ref":"#/definitions/conversion_t'
      + 'able"}},"$schema":"http://json-schema.org/draft-04/schema#","title":"T'
      + 'emperature Calculation Table","type":"object"}'
    );

    Example : (''
      + '{"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846065,192.002929'
      + '7769097,256.0039063692129,320.00488296151616,384.0058595538194,448.006'
      + '8361461226,512.0078127384259],"temperature":[307.22196722535614,309.11'
      + '53478247277,311.1188086915047,313.10025350480055,315.2137946389828,317'
      + '.2172555057597,319.2207163725366,321.2021611858325,323.3157023200148]}'
      + ',"InGaAs_Si_Difference":{"value":[1000.0,1100.090029602954,1200.044251'
      + '83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13'
      + '27555162209,1700.0869777520065,1800.0411999877924],"temperature":[1749'
      + '.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109'
      + '2,1622.3944822534868]},"Si":{"value":[0.0,64.00097659230323,128.001953'
      + '1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005'
      + '8595538194,448.0068361461226,512.0078127384259],"temperature":[546.300'
      + '048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60'
      + '4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0'
      + '002936624203]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Base of timestamps (epoch)","type":"object","required"'
      + ':["epoch","source"],"$schema":"http://json-schema.org/draft-04/schema#'
      + '","title":"Time Base","properties":{"epoch":{"description":"Date and '
      + 'time of timestamp ''0'' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:0'
      + '0+01:00).","type":"string"},"system":{"description":"Time system (time'
      + ' standard)","enum":["unknown","UTC","GPS"],"type":"string"},"source":{'
      + '"description":"Timestamp '
      + 'source","enum":["unknown","RTC","GNSS"],"type":"string"}}}'
    );

    Example : (''
      + '{"epoch":"2015-10-27T00:00:00+00:00","system":"UTC","source":"GNSS"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about position+orientation files","type":"obje'
      + 'ct","required":["time_interval","navigation_frame"],"$schema":"http://'
      + 'json-schema.org/draft-04/schema#","title":"Trajectory '
      + 'Information","properties":{"company":{"description":"Company '
      + 'name","type":"string"},"project":{"description":"Project '
      + 'name","type":"string"},"device":{"description":"Navigation device, '
      + 'e.g. '
      + 'name/type/serial","type":"string"},"settings":{"description":"Settings'
      + ' used to calculate the trajectory (descriptive '
      + 'text)","type":"string"},"software":{"description":"Software that '
      + 'calculated the trajectory (this may be the same or different software '
      + 'than the one that created the '
      + 'file)","type":"string"},"time_interval":{"description":"Time interval '
      + 'statistics","required":["minimum","average","maximum","std_dev"],"prop'
      + 'erties":{"minimum":{"description":"Minimum time interval '
      + '[s]","type":"number"},"std_dev":{"description":"Standard deviation of '
      + 'intervals [s]","type":"number"},"maximum":{"description":"Maximum time'
      + ' interval [s]","type":"number"},"average":{"description":"Average time'
      + ' interval [s]","type":"number"}},"type":"object"},"field_of_applicatio'
      + 'n":{"description":"Field of application","enum":["unknown","SLS","TLS"'
      + ',"KLS","MLS","ULS","ALS","BLS","ILS"],"type":"string"},"location":{"de'
      + 'scription":"Project location, e.g. city/state/country","type":"string"'
      + '},"navigation_frame":{"description":"Navigation frame (NED: '
      + 'North-East-Down, ENU: '
      + 'East-North-Up)","enum":["unknown","NED","ENU"],"type":"string"}}}'
    );

    Example : (''
      + '{"company":"RIEGL LMS","project":"Campaign 3","device":"IMU Model '
      + '12/1, Serial# 12345","settings":"default","software":"Navigation '
      + 'Software XYZ","time_interval":{"minimum":0.00500032,"std_dev":5.51e-07'
      + ',"maximum":0.005004883,"average":0.00500053},"field_of_application":"M'
      + 'LS","location":"Horn","navigation_frame":"NED"}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Trigger-Timestamping-Unit/IP configuration","type":"ob'
      + 'ject","required":["ttip_version","num_channel","ext_channel","ext_sign'
      + 'al","ext_delay","ext_subdivider","ext_bitmask","dmi_incr","dmi_min_tim'
      + 'e","dmi_max_time","dmi_dist_per_tick","channel","output_descr","input_'
      + 'descr","output_usage","input_usage","out_polarity","out_duration","out'
      + '_interval","out_delay","out_num_pulses","in_polarity","in_min_duration'
      + '","in_max_duration","in_max_delay"],"$schema":"http://json-schema.org/'
      + 'draft-04/schema#","title":"TTIP '
      + 'Configuration","properties":{"out_num_pulses":{"description":"number '
      + 'of output pulses to be generated, 0 .. infinite","minimum":0,"type":"i'
      + 'nteger"},"in_min_duration":{"description":"input signals with smaller '
      + 'pulse durations are ignored [0.1 '
      + 'msec]","minimum":0,"type":"integer"},"in_polarity":{"description":"0 '
      + '.. positive edge, 1 .. negative edge","minimum":0,"type":"integer"},"d'
      + 'mi_min_time":{"description":"dmi, minimum time interval between '
      + 'trigger events [0.1 msec]","minimum":0,"type":"integer"},"num_channel"'
      + ':{"description":"number of input/output channels","minimum":0,"type":"'
      + 'integer"},"dmi_max_time":{"description":"dmi, maximum time interval '
      + 'between trigger events [0.1 '
      + 'msec]","minimum":0,"type":"integer"},"ext_channel":{"description":"ID '
      + 'of channel used as external trigger input, 32 indicates none","minimum'
      + '":0,"type":"integer"},"in_max_delay":{"description":"maximum delay to '
      + 'output pulse before fake event is generated [0.1 msec], zero indicates'
      + ' that no fake events are generated","minimum":0,"type":"integer"},"dmi'
      + '_dist_per_tick":{"description":"dmi, distance per tick, just '
      + 'informative [m]","type":"number"},"out_delay":{"description":"output '
      + 'pulse initial delay after start [0.1 '
      + 'msec]","minimum":0,"type":"integer"},"input_usage":{"description":"0 '
      + '.. deactivated, 1 .. just detecting and timestamping","minimum":0,"typ'
      + 'e":"integer"},"in_max_duration":{"description":"stops measurement of '
      + 'pulse duration of input signal [0.1 msec]","minimum":0,"type":"integer'
      + '"},"output_descr":{"description":"descriptive '
      + 'string","type":"string"},"ext_bitmask":{"description":"defines which '
      + 'of the internal pulse generators are to be '
      + 'started","minimum":0,"type":"integer"},"ext_signal":{"description":"0 '
      + '.. use input signal, 1 .. use output signal of channel","minimum":0,"t'
      + 'ype":"integer"},"out_duration":{"description":"output pulse duration '
      + '[0.1 msec]","minimum":0,"type":"integer"},"ext_subdivider":{"descripti'
      + 'on":"reduces the frequency, default 1","minimum":0,"type":"integer"},"'
      + 'ttip_version":{"description":"following main.sub.ss.sss","minimum":0,"'
      + 'type":"integer"},"output_usage":{"description":"0 .. no output, 1 .. '
      + 'output derived from internal clock, 2 .. output derived from dmi, 3 ..'
      + ' output derived from external signal, 4 .. output static low, 5 .. '
      + 'output static high","minimum":0,"type":"integer"},"ext_delay":{"descri'
      + 'ption":"external trigger, time delay [0.1 '
      + 'msec]","minimum":0,"type":"integer"},"channel":{"description":"ID of '
      + 'input/output channel","minimum":0,"type":"integer"},"input_descr":{"de'
      + 'scription":"descriptive '
      + 'string","type":"string"},"out_interval":{"description":"output pulse '
      + 'interval [0.1 '
      + 'msec]","minimum":0,"type":"integer"},"dmi_incr":{"description":"dmi, '
      + 'increment in ticks","type":"integer"},"out_polarity":{"description":"0'
      + ' .. positive edge, 1 .. negative edge","minimum":0,"type":"integer"}}}'
    );

    Example : (''
      + '{"out_num_pulses":1,"in_min_duration":0,"in_polarity":0,"dmi_min_time"'
      + ':0,"num_channel":9,"dmi_max_time":0,"ext_channel":32,"in_max_delay":99'
      + '90,"dmi_dist_per_tick":0.0,"out_delay":0,"input_usage":1,"in_max_durat'
      + 'ion":10000,"output_descr":"Port 1 - Trigger","ext_bitmask":0,"ext_sign'
      + 'al":0,"out_duration":300,"ext_subdivider":1,"ttip_version":1,"output_u'
      + 'sage":1,"ext_delay":0,"channel":0,"input_descr":"Port 1 - '
      + 'Exposure","out_interval":10000,"dmi_incr":0,"out_polarity":0}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about vertex file","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","title":"Vertex Information","properties":{"v'
      + 'ertex_file":{"required":["file_extension"],"properties":{"file_extensi'
      + 'on":{"description":"Vertex file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"}},"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"vertex_file":{"file_extension":"vtx","file_uuid":"51534d95-d71f-4f36'
      + '-ae1a-3e63a21fd1c7"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"oneOf":[{"required":["size","voxel_origin","voxel_type"],"additional'
      + 'Properties":false,"properties":{"size":{"oneOf":[{"$ref":"#/definition'
      + 's/voxel_size"},{"$ref":"#/definitions/voxel_size_cubic"}],"description'
      + '":"Size of voxels in file coordinate system."},"shape_thresholds":{"$r'
      + 'ef":"#/definitions/shape_thresholds"},"voxel_type":{"$ref":"#/definiti'
      + 'ons/voxel_type"},"voxel_origin":{"$ref":"#/definitions/voxel_origin_en'
      + 'um"}}},{"required":["reference_point","size_llcs","size","voxel_origin'
      + '","voxel_type"],"additionalProperties":false,"properties":{"size_llcs"'
      + ':{"description":"Size of voxels in a locally levelled cartesian '
      + 'coordinate system (xyz). This is only used for voxels based on a map p'
      + 'rojection.","$ref":"#/definitions/voxel_size"},"reference_point":{"des'
      + 'cription":"Point in WGS84 geodetic decimal degree (EPSG:4326) that was'
      + ' used to compute the projection distortion parameters. The coefficient'
      + ' order is latitude, longitude. Only voxels with corresponding geo_tag,'
      + ' voxel_size and reference_point can be reliably processed together. '
      + 'This entry is available for voxel files in projected CRS only.","items'
      + '":{"minimum":-180,"maximum":180,"type":"number"},"minItems":2,"type":"'
      + 'array","maxItems":2},"voxel_type":{"$ref":"#/definitions/voxel_type"},'
      + '"voxel_origin":{"oneOf":[{"$ref":"#/definitions/voxel_origin_enum"},{"'
      + 'description":"The base point of the voxel grid. Used together with '
      + '<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c'
      + 'oordinates.","$ref":"#/definitions/voxel_origin_point"}]},"size":{"des'
      + 'cription":"Size of voxels in file coordinate system.","$ref":"#/defini'
      + 'tions/voxel_size"},"shape_thresholds":{"$ref":"#/definitions/shape_thr'
      + 'esholds"}}}],"description":"Details about the voxels contained in the '
      + 'file","definitions":{"voxel_size":{"description":"Size of voxels.","it'
      + 'ems":{"$ref":"#/definitions/edge_length"},"minItems":3,"type":"array",'
      + '"maxItems":3},"voxel_type":{"description":"Whether a point in a voxel '
      + 'represents its center or its centroid. If type is <tt>index</tt> there'
      + ' is no point but only an integer voxel index.","enum":["center","centr'
      + 'oid","index"],"default":"centroid"},"voxel_size_cubic":{"type":"number'
      + '","$ref":"#/definitions/edge_length"},"voxel_origin_point":{"descripti'
      + 'on":"Origin point for all voxel indices in voxel CRS.","items":{"type"'
      + ':"number"},"minItems":3,"type":"array","maxItems":3},"edge_length":{"d'
      + 'escription":"Length of voxel edge [m].","exclusiveMinimum":true,"minim'
      + 'um":0,"type":"number"},"shape_thresholds":{"description":"Thresholds '
      + 'used to compute the voxel''s shape_id value.","required":["plane","line'
      + '"],"properties":{"line":{"description":"If the biggest eigenvalue is '
      + 'bigger than the median eigenvalue * line_threshold, the voxel is '
      + 'considered a line.","exclusiveMinimum":true,"minimum":1,"type":"number'
      + '"},"plane":{"description":"If the smallest eigenvalue is smaller than '
      + 'the median eigenvalue * plane_threshold, the voxel is considered a pla'
      + 'ne.","maximum":1,"minimum":0,"exclusiveMinimum":true,"exclusiveMaximum'
      + '":true,"type":"number"}},"type":"object"},"voxel_origin_enum":{"descri'
      + 'ption":"Defines whether the voxel''s center or a corner is placed on '
      + 'CRS origin <tt>(0/0/0)</tt>.","enum":["center","corner"],"default":"co'
      + 'rner"}},"$schema":"http://json-schema.org/draft-04/schema#","title":"V'
      + 'oxel Information","type":"object"}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303,0.5143705304787237'
      + '],"reference_point":[48,16],"voxel_type":"centroid","voxel_origin":"co'
      + 'rner","size":[0.5971642834779395,0.5971642834779395,0.5143705304787237'
      + '],"shape_thresholds":{"line":6,"plane":0.16}}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Settings for waveform averaging","type":"object","requ'
      + 'ired":["num_shots","mta_zone"],"$schema":"http://json-schema.org/draft'
      + '-04/schema#","title":"Waveform Averaging '
      + 'Settings","properties":{"num_shots":{"description":"Number of '
      + 'consecutive shots to be used for averaging.","minimum":1,"type":"integ'
      + 'er"},"trim":{"description":"Percentage for robust averaging.","maximum'
      + '":0.5,"minimum":0,"type":"number","default":0},"mta_zone":{"descriptio'
      + 'n":"Fixed MTA zone for averaging.","minimum":1,"type":"integer"}}}'
    );

    Example : (''
      + '{"num_shots":7,"trim":0.05,"mta_zone":1}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about waveform files","properties":{"sample_bl'
      + 'ock_file":{"required":["file_extension"],"properties":{"file_extension'
      + '":{"description":"Sample block file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object"},"rang'
      + 'e_offset_waveform_samples_m":{"description":"Calibrated device '
      + 'specific range offset for waveform samples in meters.","type":"number"'
      + '},"sample_data_files":{"items":{"required":["channel","channel_name","'
      + 'sample_interval","sample_bits","laser_wavelength","delta_st","file_ext'
      + 'ension"],"properties":{"file_extension":{"description":"Sample data '
      + 'file extension, without the leading '
      + 'dot","type":"string"},"laser_wavelength":{"description":"Laser '
      + 'wavelength in meters (0 = unknown)","exclusiveMinimum":false,"minimum"'
      + ':0,"type":"number"},"delta_st":{"description":"reserved","type":"numbe'
      + 'r"},"channel":{"description":"Sample block channel number (255 = inval'
      + 'id)","maximum":255,"minimum":0,"exclusiveMinimum":false,"exclusiveMaxi'
      + 'mum":false,"type":"integer"},"sample_interval":{"description":"Samplin'
      + 'g interval in seconds","exclusiveMinimum":false,"minimum":0,"type":"nu'
      + 'mber"},"sample_bits":{"description":"Bitwidth of samples (e.g. 10 bit,'
      + ' 12 bit)","maximum":32,"minimum":0,"exclusiveMinimum":false,"exclusive'
      + 'Maximum":false,"type":"integer"},"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"channel_name":{"description":"Sample block '
      + 'channel name","type":"string"}},"type":"object"},"type":"array"},"rang'
      + 'e_offset_m":{"description":"Calibrated device specific range offset '
      + 'for waveform analysis by system response fitting in '
      + 'meters.","type":"number"}},"title":"Waveform Information","$schema":"h'
      + 'ttp://json-schema.org/draft-04/schema#","required":["sample_block_file'
      + '","sample_data_files"],"type":"object"}'
    );

    Example : (''
      + '{"sample_data_files":[{"file_extension":"sp0","laser_wavelength":0,"de'
      + 'lta_st":0,"channel":0,"sample_interval":1.00503e-09,"sample_bits":12,"'
      + 'file_uuid":"da084413-e3e8-4655-a122-071de8490d8e","channel_name":"high'
      + '_power"},{"file_extension":"sp1","laser_wavelength":0,"delta_st":0,"ch'
      + 'annel":1,"sample_interval":1.00503e-09,"sample_bits":12,"file_uuid":"9'
      + '3585b5e-5ea9-43a1-947b-e7ba3be642d2","channel_name":"low_power"},{"fil'
      + 'e_extension":"sp5","laser_wavelength":0,"delta_st":0,"channel":5,"samp'
      + 'le_interval":1.00503e-09,"sample_bits":12,"file_uuid":"9d2298c4-1036-4'
      + '64f-b5cb-1cf8e517f3a0","channel_name":"wwf"}],"range_offset_waveform_s'
      + 'amples_m ":7.283,"sample_block_file":{"file_extension":"sbx","file_uui'
      + 'd":"93a03615-66c0-4bea-8ff8-c577378fe660"},"range_offset_m":3.1415}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"items":{"required":["sbl_name","enabled","channel_idx_mask"],"proper'
      + 'ties":{"pass_rng_greater":{"description":"Threshold for range greater '
      + 'than [m]","type":"number"},"enabled":{"description":"Waveform output '
      + 'enabled","type":"boolean"},"pass_dev_less":{"description":"Threshold '
      + 'for deviation less than '
      + '[1]","type":"integer"},"pass_rng_less":{"description":"Threshold for '
      + 'range less than '
      + '[m]","type":"number"},"channel_idx_mask":{"description":"Bit mask for '
      + 'channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = Bit1,'
      + ' ...","type":"integer"},"pass_dev_greater":{"description":"Threshold '
      + 'for deviation greater than '
      + '[1]","type":"integer"},"smart_enabled":{"description":"Smart waveform '
      + 'output '
      + 'enabled","type":"boolean"},"pass_ampl_less":{"description":"Threshold '
      + 'for amplitude less than '
      + '[dB]","type":"number"},"pass_ampl_greater":{"description":"Threshold '
      + 'for amplitude greater than '
      + '[dB]","type":"number"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"sbl_name":{"description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf","type":"string"}},"type":"object"},"description":"Scanner '
      + 'settings for waveform output","$schema":"http://json-schema.org/draft-'
      + '04/schema#","title":"Waveform Settings","type":"array"}'
    );

    Example : (''
      + '[{"pass_rng_greater":9.27,"enabled":true,"pass_rng_less":13.11,"channe'
      + 'l_idx_mask":11,"smart_enabled":true,"pass_ampl_less":5.0,"pass_ampl_gr'
      + 'eater":1.0,"sbl_name":"wfm"},{"enabled":false,"channel_idx_mask":32,"s'
      + 'bl_name":"wwf"}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Window analysis data estimated from scandata and '
      + 'resulting filter parameters","type":"object","required":["result","fil'
      + 'ter","settings"],"$schema":"http://json-schema.org/draft-04/schema#","'
      + 'title":"Window Analysis","properties":{"result":{"required":["angle","'
      + 'range_mean","range_sigma","amplitude_mean","amplitude_sigma","amplitud'
      + 'e_offset"],"properties":{"angle":{"description":"[deg]","items":{"type'
      + '":"number"},"type":"array"},"amplitude_offset":{"description":"[dB]","'
      + 'items":{"type":"number"},"type":"array"},"range_mean":{"description":"'
      + '[m]","items":{"type":"number"},"type":"array"},"timestamp":{"descripti'
      + 'on":"[s]","items":{"type":"number"},"type":"array"},"range_sigma":{"de'
      + 'scription":"[m]","items":{"type":"number"},"type":"array"},"amplitude_'
      + 'sigma":{"description":"[dB]","items":{"type":"number"},"type":"array"}'
      + ',"amplitude_mean":{"description":"[dB]","items":{"type":"number"},"typ'
      + 'e":"array"}},"type":"object"},"filter":{"required":["angle","range_min'
      + '","range_max","amplitude_max"],"properties":{"angle":{"description":"['
      + 'deg]","items":{"type":"number"},"type":"array"},"range_min":{"descript'
      + 'ion":"[m]","items":{"type":"number"},"type":"array"},"amplitude_max":{'
      + '"description":"[dB]","items":{"type":"number"},"type":"array"},"range_'
      + 'max":{"description":"[m]","items":{"type":"number"},"type":"array"}},"'
      + 'type":"object"},"settings":{"required":["range","amplitude"],"properti'
      + 'es":{"amplitude":{"required":["sigma_factor","additive_value"],"proper'
      + 'ties":{"sigma_factor":{"type":"number"},"additive_value":{"type":"numb'
      + 'er"}},"type":"object"},"range":{"required":["sigma_factor","additive_v'
      + 'alue"],"properties":{"sigma_factor":{"type":"number"},"additive_value"'
      + ':{"type":"number"}},"type":"object"}},"type":"object"}}}'
    );

    Example : (''
      + '{"result":{"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,'
      + '15.9],"amplitude_offset":[1.9,1.9],"range_mean":[0.1105621,0.1079564,0'
      + '.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.'
      + '1058445,0.1031261],"timestamp":[408.4441,411.4443],"range_sigma":[0.01'
      + '869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.019553'
      + '29,0.02225589,0.02229977,0.01899122,0.02009433],"amplitude_sigma":[0.4'
      + '272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.4'
      + '472798,0.4346001,0.4345487,0.4540681],"amplitude_mean":[5.347396,5.263'
      + '155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.0'
      + '02441,4.982]},"filter":{"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15'
      + '.6,15.7,15.8,15.9],"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.2'
      + '18,-0.219,-0.221,-0.223,-0.225,-0.227],"amplitude_max":[8.04,8.01,7.99'
      + ',7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],"range_max":[0.424,0.425,0.426'
      + ',0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432]},"settings":{"amplitu'
      + 'de":{"sigma_factor":4,"additive_value":1.0},"range":{"sigma_factor":8,'
      + '"additive_value":0.1}}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Correction parameters for window glass echoes","type":'
      + '"object","required":["amplitude","range","slices"],"$schema":"http://j'
      + 'son-schema.org/draft-04/schema#","title":"Window Echo '
      + 'Correction","properties":{"amplitude":{"description":"Amplitude axis '
      + 'of correction table","required":["minimum","maximum","entries"],"prope'
      + 'rties":{"entries":{"description":"Number of amplitude entries","minimu'
      + 'm":1,"type":"integer"},"minimum":{"description":"Minimum amplitude in '
      + 'dB","minimum":0.0,"type":"number"},"maximum":{"description":"Maximum '
      + 'amplitude in dB","minimum":0.0,"type":"number"}},"type":"object"},"sli'
      + 'ces":{"items":{"description":"Window echo correction parameter slice",'
      + '"required":["amplitude","table"],"properties":{"amplitude":{"descripti'
      + 'on":"Window echo amplitude of slice in '
      + 'dB","type":"number"},"table":{"description":"Correction table '
      + '(dimension defined by the ''amplitude'' and ''range'' '
      + 'objects)","items":{"description":"Table row (= amplitude '
      + 'axis)","items":{"description":"Table column (= range '
      + 'axis)","items":{"description":"Table cell (item 0: amplitude in dB, 1:'
      + ' range in m, 2: flags)","type":"number"},"minItems":3,"type":"array","'
      + 'maxItems":3},"minItems":1,"type":"array"},"minItems":1,"type":"array"}'
      + '},"type":"object"},"type":"array"},"range":{"description":"Range axis '
      + 'of correction table","required":["minimum","maximum","entries"],"prope'
      + 'rties":{"entries":{"description":"Number of range entries","minimum":1'
      + ',"type":"integer"},"minimum":{"description":"Minimum range in m","maxi'
      + 'mum":2.0,"minimum":-2.0,"type":"number"},"maximum":{"description":"Max'
      + 'imum range in '
      + 'm","maximum":2.0,"minimum":-2.0,"type":"number"}},"type":"object"}}}'
    );

    Example : (''
      + '{"amplitude":{"entries":128,"minimum":2,"maximum":20},"slices":[{"ampl'
      + 'itude":1.5,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]},{"amplitude'
      + '":2.0,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}],"range":{"entri'
      + 'es":128,"minimum":-1.5060822940732335,"maximum":1.5060822940732335}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
